.. highlight:: cython

=============
Compilation
=============

.. note::

    The sections in this page were moved to the :ref:`compilation` in the userguide.


Compiling from the command line
===============================

This section was moved to :ref:`compiling_command_line`.

Compiling with ``distutils``
============================

This section was moved to :ref:`basic_setup.py`.

Configuring the C-Build
------------------------

This section was moved to :ref:`basic_setup.py`.

Cythonize arguments
-------------------

This section was moved to :ref:`cythonize_arguments`.

Compiler options
----------------

This section was moved to :ref:`compiler_options`.

Distributing Cython modules
----------------------------

This section was moved to :ref:`distributing_cython_modules`.

Integrating multiple modules
============================

This section was moved to :ref:`integrating_multiple_modules`.

Compiling with :mod:`pyximport`
===============================

This section was moved to :ref:`pyximport`.

Arguments
---------

Dependency Handling
--------------------

Limitations
------------

Compiling with ``cython.inline``
=================================

This section was moved to :ref:`compiling_with_cython_inline`.

Compiling with Sage
===================

This section was moved to :ref:`compiling_with_sage`.

Compiling with a Jupyter Notebook
=================================

This section was moved to :ref:`compiling_notebook`.

Compiler directives
====================

This section was moved to :ref:`compiler-directives`.

Configurable optimisations
--------------------------

This section was moved to :ref:`configurable_optimisations`.

Warnings
--------

This section was moved to :ref:`warnings`.

How to set directives
---------------------

This section was moved to :ref:`how_to_set_directives`.

Globally
:::::::::

Locally
::::::::

In :file:`setup.py`
:::::::::::::::::::
